package com.example;

import java.util.Random;
import java.util.function.Consumer;
import java.util.function.Supplier;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.cloud.schema.registry.client.EnableSchemaRegistryClient;
import org.springframework.cloud.schema.registry.client.SchemaRegistryClient;
import org.springframework.cloud.stream.function.StreamBridge;
import org.springframework.context.annotation.Bean;
import org.springframework.util.MimeType;

import reactor.util.function.Tuple2;
import reactor.util.function.Tuples;

@SpringBootApplication
@EnableSchemaRegistryClient
public class TestAvroSpringBootApplication implements CommandLineRunner {

    @Autowired
    private StreamBridge streamBridge;

    @Autowired
    SchemaRegistryClient client;

    public static void main(String[] args) {
        SpringApplication.run(TestAvroSpringBootApplication.class, args);
    }

    @Override
    public void run(String... args) throws Exception {
        Random random = new Random();
        Sensor sensor = Sensor.newBuilder()
            .setId("sensor")
            .setAcceleration(random.nextFloat())
            .setTemperature(random.nextFloat())
            .setVelocity(random.nextFloat())
            .build();
        send(sensor);
    }

    void send(Sensor sensor) {
//        streamBridge.send("sensor", sensor, MimeType.valueOf("application/+avro"));
    }

    @Bean
    public Supplier<Sensor> supplier() {
        Random random = new Random();
        return () -> Sensor.newBuilder()
            .setId("id")
            .setTemperature(random.nextFloat())
            .setAcceleration(random.nextFloat())
            .setVelocity(random.nextFloat())
            .build();
    }

    @Bean
    public Consumer<Sensor> consume() {
        return (sensor) -> { 
            System.out.println("Received Type:" + sensor.getClass().getCanonicalName());
            System.out.println("Received:" + sensor);
            };
    }

}
